@@ -22,7 +22,7 @@ GEOGIT_DATASTORE_NAME = 'DEFAULT_NAME'
 LOCKDOWN_GEONODE = True
 REGISTRATION_OPEN = False
 SOCIAL_BUTTONS = False
-
+MODIFY_TOPICCATEGORY = False
 # Set to True to load non-minified versions of (static) client dependencies
 DEBUG_STATIC = False
 
@@ -35,12 +35,6 @@ DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
         'NAME': os.path.join(PROJECT_ROOT, 'development.db'),
-    },
-    'geonode_imports': {
-        'ENGINE': 'django.contrib.gis.db.backends.postgis',
-        'NAME': 'geonode_imports',
-        'USER': 'geonode',
-        'PASSWORD': 'geonode',
     }
 }
 
@@ -60,14 +54,14 @@ OGC_SERVER = {
         'BACKEND_WRITE_ENABLED': True,
         'WPS_ENABLED': False,
         # Set to name of database in DATABASES dictionary to enable
-        'DATASTORE': 'geonode_imports',
+        'DATASTORE': '',
         'TIMEOUT': 10,  # The maximum time to wait for the server to respond.
     }
 }
 
 # Uploader Settings
 UPLOADER = {
-    'BACKEND': 'geonode.importer',
+    'BACKEND': 'geonode.rest',
     'OPTIONS': {
         'TIME_ENABLED': False,
         'GEOGIT_ENABLED': True,
@@ -116,10 +110,12 @@ MAX_DOCUMENT_SIZE = 2  # MB
 
 
 INSTALLED_APPS = (
+    'django.contrib.gis',
     'geoshape.file_service',
     'geoshape.core',
     'django_classification_banner',
     'maploom',
+    'iaff_geoshape'
 ) + INSTALLED_APPS
 
 LOGGING = {
@@ -155,18 +151,21 @@ LOGGING = {
     },
     "loggers": {
         "django": {
-            "handlers": ["console"],
+            "handlers": ["console", "mail_admins"],
             "level": "ERROR",
         },
         "geoshape": {
-            "handlers": ["console"],
+            "handlers": ["console", "mail_admins"],
             "level": "DEBUG",
         },
         "geonode": {
-            "handlers": ["console"],
+            "handlers": ["console", "mail_admins"],
             "level": "DEBUG",
         },
-
+        "iaff_geoshape": {
+            "handlers": ["console", "mail_admins"],
+            "level": "ERROR",
+        },
         "gsconfig.catalog": {
             "handlers": ["console"],
             "level": "ERROR",
@@ -188,7 +187,6 @@ LOGGING = {
 
 TEMPLATE_CONTEXT_PROCESSORS += (
     'django_classification_banner.context_processors.classification',
-    'geoshape.core.context_processors.security_warnings'
 )
 
 # Add additional paths (as regular expressions) that don't require authentication.
@@ -197,6 +195,11 @@ AUTH_EXEMPT_URLS = ('/file-service/*', '/i18n/setlang/',)
 if LOCKDOWN_GEONODE:
     MIDDLEWARE_CLASSES = MIDDLEWARE_CLASSES + ('geonode.security.middleware.LoginRequiredMiddleware',)
 
+# Load more settings from a file called local_settings.py if it exists
+try:
+    from local_settings import *  # noqa
+except ImportError:
+    pass
 
 MAP_BASELAYERS = [
     {
@@ -219,9 +222,4 @@ MAP_BASELAYERS = [
     }
 ]
 
-
-# Load more settings from a file called local_settings.py if it exists
-try:
-    from local_settings import *  # noqa
-except ImportError:
-    pass
+DATABASE_ROUTERS = ['iaff_geoshape.routers.IAFFGeoRouter',]
